Module changeset

Module changeset 

Functions

scope_command_to_changeset
Given a list of changed file paths and a base command, rewrite the command to scope it to only the affected packages/crates. Returns None if no scoping is possible (run the full command).