scope_command_to_changeset

Function scope_command_to_changeset 

pub fn scope_command_to_changeset(
    command: &str,
    changed_files: &[String],
) -> Option<String>
Given a list of changed file paths and a base command, rewrite the command to scope it to only the affected packages/crates. Returns None if no scoping is possible (run the full command).