Structs
- Changed
File - A file that has changed in the current changeset.
- Check
Context - Contextual data gathered from the Engine’s graph stores and the changeset, providing both before (DB) and after (parsed) snapshots for comparison.
Traits
- Semantic
Check - Trait that every semantic check must implement.