Functions
- build_
check_ context - Build a
CheckContextby querying the Engine’s graph stores for the “before” snapshot and parsing the materialized changeset files for the “after” snapshot.
CheckContext by querying the Engine’s graph stores for the
“before” snapshot and parsing the materialized changeset files for the
“after” snapshot.