Module checks

Module checks 

Structs

ChangedFile
A file that has changed in the current changeset.
CheckContext
Contextual data gathered from the Engine’s graph stores and the changeset, providing both before (DB) and after (parsed) snapshots for comparison.

Traits

SemanticCheck
Trait that every semantic check must implement.